searchData={"items":[{"type":"module","title":"Cldr.Plug","doc":"Functions to support setting the locale\nfor Cldr and/or Gettext from the session.","ref":"Cldr.Plug.html"},{"type":"function","title":"Cldr.Plug.put_locale_from_session/2","doc":"Puts the locale from the session into the current\nprocess for `Cldr` and/or `Gettext`.\n\nThis function is useful to place in the `on_mount`\ncallback for a LiveView.","ref":"Cldr.Plug.html#put_locale_from_session/2"},{"type":"function","title":"Arguments - Cldr.Plug.put_locale_from_session/2","doc":"* `session` is any map, typically the map returned\n  as part of the `conn` of a Phoenix or Plug request,\n  A `session` is passed as the third parameter to the\n  `on_mount` callback of a LiveView request.\n\n* `applications` is a list of applications for which\n  the locale may be set. The valid options are `:cldr`\n  and `:gettext`. The default is `[:cldr, :gettext]`","ref":"Cldr.Plug.html#put_locale_from_session/2-arguments"},{"type":"function","title":"Returns - Cldr.Plug.put_locale_from_session/2","doc":"* `{:ok, locale}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Plug.html#put_locale_from_session/2-returns"},{"type":"function","title":"Example - Cldr.Plug.put_locale_from_session/2","doc":"=> Cldr.Plug.put_locale_from_session(session)\n    => Cldr.Plug.put_locale_from_session(session, [:cldr])\n    => Cldr.Plug.put_locale_from_session(session, [:cldr, :gettext])\n\n    # In a LiveView\n    def on_mount(:default, _params, session, socket) do\n      {:ok, locale} = Cldr.Plug.put_locale_from_session(session)\n    end","ref":"Cldr.Plug.html#put_locale_from_session/2-example"},{"type":"type","title":"Cldr.Plug.application/0","doc":"","ref":"Cldr.Plug.html#t:application/0"},{"type":"type","title":"Cldr.Plug.applications/0","doc":"","ref":"Cldr.Plug.html#t:applications/0"},{"type":"module","title":"Cldr.Plug.AcceptLanguage","doc":"Parses the accept-language header if one is available and sets\n`conn.private[:cldr_locale]` accordingly.  The locale can\nbe later retrieved by `Cldr.Plug.AcceptLanguage.get_cldr_locale/1`","ref":"Cldr.Plug.AcceptLanguage.html"},{"type":"module","title":"Options - Cldr.Plug.AcceptLanguage","doc":"* `:cldr_backend` is any backend module. The default\n  is `Cldr.default_backend/0`. If no `:cldr_backend`\n  option is provided and no default backend is configured\n  then an exception will be raised.\n\n* `:no_match_log_level` determines the logging level for\n  the case when no matching locale is configured to meet the users\n  request. The default is `:warning`. If set to `nil` then no logging\n  is performed.","ref":"Cldr.Plug.AcceptLanguage.html#module-options"},{"type":"module","title":"Example - Cldr.Plug.AcceptLanguage","doc":"# Using a specific backend to validate\n    # and match locales\n    plug Cldr.Plug.AcceptLanguage,\n      cldr_backend: MyApp.Cldr\n\n    # Using the default backend to validate\n    # and match locales\n    plug Cldr.Plug.AcceptLanguage","ref":"Cldr.Plug.AcceptLanguage.html#module-example"},{"type":"function","title":"Cldr.Plug.AcceptLanguage.best_match/2","doc":"Returns the locale which is the best match for the provided\naccept-language header","ref":"Cldr.Plug.AcceptLanguage.html#best_match/2"},{"type":"function","title":"Cldr.Plug.AcceptLanguage.get_cldr_locale/1","doc":"Return the locale set by `Cldr.Plug.AcceptLanguage`","ref":"Cldr.Plug.AcceptLanguage.html#get_cldr_locale/1"},{"type":"module","title":"Cldr.Plug.PutLocale","doc":"Puts the Cldr and/or Gettext locales derived from the accept-language\nheader, a query parameter, a url parameter, a body parameter, the route\n or the session for the current process with `Cldr.put_locale/2` and/or\n`Gettext.put_locale/2`.","ref":"Cldr.Plug.PutLocale.html"},{"type":"module","title":"Options - Cldr.Plug.PutLocale","doc":"* `:apps` - list of apps for which to set locale.\n    See the apps configuration section.\n\n  * `:from` - where in the request to look for the locale.\n    The default is `[:session, :accept_language, :query, :path, :route]`. The valid\n    options are:\n    * `:accept_language` will parse the `accept-language` header\n       and finds the best matched configured locale\n    * `:path` will look for a locale by examining `conn.path_params`\n    * `:query` will look for a locale by examining `conn.query_params`\n    * `:body` will look for a locale by examining `conn.body_params`\n    * `:cookie` will look for a locale in the request cookie(s)\n    * `:session` will look for a locale in the session\n    * `:route` will look for a locale in the route that was\n      matched under the key `private.:cldr_locale`.\n      The key may be populated by a Phoenix router and it is used\n      extensively by the [ex_cldr_routes](https://hex.pm/packages/ex_cldr_routes)\n      library. Note that any locale set in the route represents\n      the locale defined for the route, not necessarily one requested\n      by the user. Therefore setting the locale from the `:route` key\n      should be a lower priority than other methods based on the actual\n      request.\n    * `:host` will attempt to resolve a locale from the host name top-level\n      domain using `Cldr.Locale.locale_from_host/3`\n    * `{Module, function, args}` in which case the indicated function will\n      be called.  If it returns `{:ok, locale}` then the locale is set to\n      `locale`. `locale` must be a `t:Cldr.LanguageTag.t()`.\n      Any other return is considered an error and no locale will be set.\n      When calling the function, `conn` and `options` will be prepended to `args`.\n    * `{Module, function}` in which case the function is called with\n      `conn` and `options` as its two arguments. All other behaviour is the same\n      as that for a `{Module, function, args}` option.\n\n  * `:default` - the default locale to set if no locale is\n    found by other configured methods.  It can be a string like \"en\"\n    or a `Cldr.LanguageTag` struct. It may also be `:none` to indicate\n    that no locale is to be set by default. Lastly, it may also be a\n    `{Module, function, args}` or `{Module, function}` tuple. The default is\n    `Cldr.default_locale/1`. If the case of `{Module, function, args}`,\n    a return of `{:ok, %Cldr.LanguageTag{}}` will set the locale. Any other\n    return will not set a locale.\n\n  * `:gettext` - the name of the `Gettext` backend module upon which\n    the locale will be validated. This option is not required if a\n    gettext module is specified in the `:apps` configuration.\n\n  * `:cldr` - the name of the `Cldr` backend module upon which\n    the locale will be validated.  This option is not required if a\n    gettext module is specified in the `:apps` configuration.\n\n  * `:session_key` - defines the key used to look for the locale\n    in the session.  The default is `cldr_locale`. This option is\n    deprecated and will be removed in a future release. The session\n    key is being standardised in order to faciliate a simpler integration\n    with [Phoenix LiveView](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.html)\n    by ensuring that the session key is always under a well known\n    key.\n\nIf a locale is found then `conn.private[:cldr_locale]` is also set.\nIt can be retrieved with `Cldr.Plug.PutLocale.get_cldr_locale/1`.","ref":"Cldr.Plug.PutLocale.html#module-options"},{"type":"module","title":"App configuration - Cldr.Plug.PutLocale","doc":"The `:apps` configuration key defines which applications will have\ntheir locale *set* by this plug.\n\n`Cldr.Plug.PutLocale` can set the locale for `cldr`, `gettext` or both.\nThe basic configuration of the `:app` key is an atom, or list of atoms,\ncontaining one or both of these app names.  For example:\n\n    apps: :cldr\n    apps: :gettext\n    apps: [:cldr, :gettext]\n\nIn each of these cases, the locale is set globally\n**for the current process**.\n\nSometimes setting the locale for only a specific backend is required.\nIn this case, configure the `:apps` key as a keyword list pairing an\napplication with the required backend module.  The value `:global` signifies\nsetting the local for the global context. For example:\n\n    apps: [cldr: MyApp.Cldr]\n    apps: [gettext: MyAppGettext]\n    apps: [gettext: :global]\n    apps: [cldr: MyApp.Cldr, gettext: MyAppGettext]","ref":"Cldr.Plug.PutLocale.html#module-app-configuration"},{"type":"module","title":"Using Cldr.Plug.PutLocale without Phoenix - Cldr.Plug.PutLocale","doc":"If you are using `Cldr.Plug.PutLocale` without Phoenix and you\nplan to use `:path_param` to identify the locale of a request\nthen `Cldr.Plug.PutLocale` must be configured *after* `plug :match`\nand *before* `plug :dispatch`.  For example:\n\n    defmodule MyRouter do\n      use Plug.Router\n\n      plug :match\n\n      plug Cldr.Plug.PutLocale,\n        apps: [:cldr, :gettext],\n        from: [:path, :query],\n        gettext: MyApp.Gettext,\n        cldr: MyApp.Cldr\n\n      plug :dispatch\n\n      get \"/hello/:locale\" do\n        send_resp(conn, 200, \"world\")\n      end\n    end","ref":"Cldr.Plug.PutLocale.html#module-using-cldr-plug-putlocale-without-phoenix"},{"type":"module","title":"Using Cldr.Plug.PutLocale with Phoenix - Cldr.Plug.PutLocale","doc":"If you are using `Cldr.Plug.PutLocale` with Phoenix and you plan\nto use the `:path_param` to identify the locale of a request then\n`Cldr.Plug.PutLocale` must be configured in the router module, *not*\nin the endpoint module. This is because `conn.path_params` has\nnot yet been populated in the endpoint. For example:\n\n    defmodule MyAppWeb.Router do\n      use MyAppWeb, :router\n\n      pipeline :browser do\n        plug :accepts, [\"html\"]\n        plug :fetch_session\n        plug Cldr.Plug.PutLocale,\n    \t    apps: [:cldr, :gettext],\n    \t    from: [:path, :query],\n    \t    gettext: MyApp.Gettext,\n    \t    cldr: MyApp.Cldr\n        plug :fetch_flash\n        plug :protect_from_forgery\n        plug :put_secure_browser_headers\n      end\n\n      scope \"/:locale\", HelloWeb do\n        pipe_through :browser\n\n        get \"/\", PageController, :index\n      end\n    end","ref":"Cldr.Plug.PutLocale.html#module-using-cldr-plug-putlocale-with-phoenix"},{"type":"module","title":"Examples - Cldr.Plug.PutLocale","doc":"# Will set the global locale for the current process\n    # for both `:cldr` and `:gettext`\n    plug Cldr.Plug.PutLocale,\n      apps:    [:cldr, :gettext],\n      from:    [:query, :path, :body, :cookie, :accept_language],\n      param:   \"locale\",\n      gettext: GetTextModule,\n      cldr:    MyApp.Cldr\n\n    # Will set the backend-only locale for the current process\n    # for both `:cldr` and `:gettext`\n    plug Cldr.Plug.PutLocale,\n      apps:    [cldr: MyApp.Cldr, gettext: GetTextModule],\n      from:    [:query, :path, :body, :cookie, :accept_language],\n      param:   \"locale\"\n\n    # Will set the backend-only locale for the current process\n    # for `:cldr` and globally for `:gettext`\n    plug Cldr.Plug.PutLocale,\n      apps:    [cldr: MyApp.Cldr, gettext: :global],\n      from:    [:query, :path, :body, :cookie, :accept_language],\n      param:   \"locale\"","ref":"Cldr.Plug.PutLocale.html#module-examples"},{"type":"function","title":"Cldr.Plug.PutLocale.get_cldr_locale/1","doc":"Return the locale set by `Cldr.Plug.PutLocale`","ref":"Cldr.Plug.PutLocale.html#get_cldr_locale/1"},{"type":"function","title":"Cldr.Plug.PutLocale.session_key/0","doc":"Returns the name of the session key used\nto store the CLDR locale name.","ref":"Cldr.Plug.PutLocale.html#session_key/0"},{"type":"function","title":"Example - Cldr.Plug.PutLocale.session_key/0","doc":"iex> Cldr.Plug.PutLocale.session_key()\n  \"cldr_locale\"","ref":"Cldr.Plug.PutLocale.html#session_key/0-example"},{"type":"module","title":"Cldr.Plug.PutSession","doc":"Puts the CLDR locale in the session.\n\nThe session key is fixed to be `cldr_locale`\nin order that downstream functions like those in `liveview` don't\nhave to be passed options.","ref":"Cldr.Plug.PutSession.html"},{"type":"module","title":"Options - Cldr.Plug.PutSession","doc":"* `:as` is an options that determines the format in which\n  the locale is saved in the session. That valid settings\n  for this options are:\n\n  * `:string` in which the current locale is converted\n    to a string before storing in the session. It will then\n    be parsed back into a `%Cldr.LanguageTag{}` upon\n    reading it from the session.  This option has the benefit\n    that it will minimise space used in the session at the\n    expense of the CPU time required to serialized and parse.\n    The average size of commonly used locales is under 10 bytes\n    and often less than 5.\n\n  * `:language_tag` in which the current locale is stored\n    in the session in its native `%Cldr.LanguageTag{}`\n    format. This has the benefit of minimizing CPU time\n    serialising and parsing the locale at the expense of\n    a larger payment size in the session. The average\n    size of a language tag struct, when serialized, is\n    around 500 bytes.\n\nThe default is `as: :string`.","ref":"Cldr.Plug.PutSession.html#module-options"},{"type":"module","title":"Examples - Cldr.Plug.PutSession","doc":"# Define a router module that\n    # sets the locale for the current process\n    # and then also sets it in the session\n\n    defmodule MyAppWeb.Router do\n      use MyAppWeb, :router\n\n      pipeline :browser do\n        plug :accepts, [\"html\"]\n        plug :fetch_session\n        plug Cldr.Plug.PutLocale,\n    \t    apps: [:cldr, :gettext],\n    \t    from: [:path, :query],\n    \t    gettext: MyApp.Gettext,\n    \t    cldr: MyApp.Cldr\n        plug Cldr.Plug.PutSession, as: :string\n        plug :fetch_flash\n        plug :protect_from_forgery\n        plug :put_secure_browser_headers\n      end\n    end","ref":"Cldr.Plug.PutSession.html#module-examples"},{"type":"extras","title":"Cldr Plug","doc":"# Cldr Plug","ref":"readme.html"},{"type":"extras","title":"Installation - Cldr Plug","doc":"The package can be installed by adding `ex_cldr_plugs` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_cldr_plugs, \"~> 1.3\"},\n  ]\nend\n```\nDocumentation can be found at [https://hexdocs.pm/ex_cldr_plugs](https://hexdocs.pm/ex_cldr_plugs).","ref":"readme.html#installation"},{"type":"extras","title":"Plugs - Cldr Plug","doc":"`Cldr` provides two plugs to aid integration into an HTTP workflow.  These two plugs are:\n\n* `Cldr.Plug.AcceptLanguage` which will parse an `accept-language` header and resolve the best matched and configured `Cldr` locale. The result is stored in `conn.private[:cldr_locale]` which is also returned by `Cldr.Plug.AcceptLanguage.get_cldr_locale/1`.\n\n* `Cldr.Plug.PutLocale` which will look for a locale in the several places and then call `Cldr.put_locale/2` and `Gettext.put_locale/2` if configured so to do. Finally, The result is stored in `conn.private[:cldr_locale]` which is then available through `Cldr.Plug.PutLocale.get_cldr_locale/1`. The plug will look for a locale in the following locations depending on the plug configuration:\n\n  * `path_params`\n  * `query_params`\n  * `body_params`\n  * `cookies`\n  * `accept-language` header\n  * Hostname suffix\n  * the `session`\n  * An `{Module, function, [args]}` or `{Module, function}` tuple that should return `{:ok, Cldr.LanguageTag.t()}` - any other return will not set the locale.\n\nSee `Cldr.Plug.PutLocale` for a description of how to configure the plug.\n\nIn addition, note that when migrating from `ex_cldr` 1.x versions, a backend needs to be configured for both plugs. In the simplest case an example would be:\n```elixir\nplug Cldr.Plug.PutLocale,\n  apps:    [:cldr],\n  cldr:    MyApp.Cldr\n\nplug Cldr.Plug.AcceptLanguage,\n  cldr_backend: MyApp.Cldr\n```","ref":"readme.html#plugs"},{"type":"extras","title":"Using Cldr.Plug.PutLocale without Phoenix - Cldr Plug","doc":"If you are using `Cldr.Plug.PutLocale` without Phoenix and you plan to use `:path_param` to identify the locale of a request then `Cldr.Plug.PutLocale` must be configured *after* `plug :match` and *before* `plug :dispatch`.  For example:\n```elixir\ndefmodule MyRouter do\n  use Plug.Router\n\n  plug :match\n\n  plug Cldr.Plug.PutLocale,\n    apps: [:cldr, :gettext],\n    from: [:path, :query],\n    gettext: MyApp.Gettext,\n    cldr: MyApp.Cldr\n\n  plug :dispatch\n\n  get \"/hello/:locale\" do\n    send_resp(conn, 200, \"world\")\n  end\nend\n```","ref":"readme.html#using-cldr-plug-putlocale-without-phoenix"},{"type":"extras","title":"Using Cldr.Plug.PutLocale with Phoenix - Cldr Plug","doc":"If you are using `Cldr.Plug.PutLocale` with Phoenix and you plan to use the `:path_param` to identify the locale of a request then `Cldr.Plug.PutLocale` must be configured in the router module, *not* in the endpoint module. This is because `conn.path_params` has not yet been populated in the endpoint. For example:\n```elixir\ndefmodule MyAppWeb.Router do\n  use MyAppWeb, :router\n\n  pipeline :browser do\n    plug :accepts, [\"html\"]\n    plug :fetch_session\n    plug Cldr.Plug.PutLocale,\n      apps: [:cldr, :gettext],\n      from: [:path, :query],\n      gettext: MyApp.Gettext,\n      cldr: MyApp.Cldr\n    plug :fetch_flash\n    plug :protect_from_forgery\n    plug :put_secure_browser_headers\n  end\n\n  scope \"/:locale\", HelloWeb do\n    pipe_through :browser\n\n    get \"/\", PageController, :index\n  end\n\nend\n```","ref":"readme.html#using-cldr-plug-putlocale-with-phoenix"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n**Elixir version 1.11 or greater is required from ex_cldr_plugs version 1.3.1**","ref":"changelog.html"},{"type":"extras","title":"Cldr Plugs v1.3.3 - Changelog","doc":"This is the changelog for Cldr Plugs v1.3.3 released on May 3rd, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_plugs/tags)","ref":"changelog.html#cldr-plugs-v1-3-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Add `config/prod.exs` so `MIX_ENV=prod` compilation succeeds. Thanks to @camelpunch for the report. Closes #12.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Plugs v1.3.2 - Changelog","doc":"This is the changelog for Cldr Plugs v1.3.2 released on April 9th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_plugs/tags)","ref":"changelog.html#cldr-plugs-v1-3-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix spec for `put_locale_from_session/2`. Thanks to @woylie for the PR. Closes #4.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Plugs v1.3.1 - Changelog","doc":"This is the changelog for Cldr Plugs v1.3.1 released on October 28th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_plugs/tags)","ref":"changelog.html#cldr-plugs-v1-3-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix default log level to be `:warning`, not `:warn`. Thanks to @philipgiuliani for the PR. Closes #9.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Plugs v1.3.0 - Changelog","doc":"This is the changelog for Cldr Plugs v1.3.0 released on April 28th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_plugs/tags)","ref":"changelog.html#cldr-plugs-v1-3-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [ex_cldr version 2.37.0](https://hex.pm/packages/ex_cldr/2.37.0) which includes data from [CLDR release 43](https://cldr.unicode.org/index/downloads/cldr-43)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Plugs v1.2.1 - Changelog","doc":"This is the changelog for Cldr Plugs v1.2.1 released on January 30th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_plugs/tags)","ref":"changelog.html#cldr-plugs-v1-2-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Improves logger messages when `Cldr.Plug.PutLocale` is attempting to set the Gettext locale. There are now one of two warnings logged:\n  * One when the CLDR backend module has no configured Gettext module\n  * One when there is a configured Gettext module but that module does not have the specified locale configured.\n  \n* Changes `Logger.warn/1` to `Logger.warning/1` to avoid deprecation messages on Elixir 1.15","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Plugs v1.2.0 - Changelog","doc":"This is the changelog for Cldr Plugs v1.2.0 released on July 27th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_plugs/tags)","ref":"changelog.html#cldr-plugs-v1-2-0"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Deprecate `Cldr.Plug.SetLocale` in favour of the more consistent `Cldr.Plug.PutLocale` name.\n\n* Deprecate the `:assigns` `from` key in favour of they key `:route`. `Cldr.Route` will, as of version 0.5.0, place the locale in the `conn.private.cldr_locale` location.  `from: :route` better reflects the intent.  The `:assigns` keyword remains valid with a deprecation warning.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix setting the locale from the result returned from an `{M, f}` or `{M, f, [a]}`. Thanks to @rubas for the PR.\n\n* Don't make modules `Cldr.Plug.AcceptLanguage` and `Cldr.Plug.PutSession` dependent on `Plug`, `Plug` is a required dependency since this library was split from `ex_cldr`. Thanks to @linusdm for the report. Closes #1.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.Plug.put_locale_from_session/2` that takes the locale from the session (if there is one) and puts the Cldr locale and/or the Gettext locale into the current process.  This is very useful to add to the `on_mount` callback in LiveView but it can be applied at any time the session is available. For example:\n```elixir\ndef on_mount(:default, _params, session, socket) do\n  {:ok, locale} = Cldr.Plug.put_locale_from_session(session)\n  ....\nend\n```\n\n* `Cldr.Plug.PutSession` now has the option to store the full `%Cldr.LanguageTag{}` into the session, or just the string representation (which the default and the same as previous releases). The tradeoff is space used the session (less than 10 bytes typically for the string, around 500 bytes for the struct) versus the performance hit serializing and parsing the locale when storing it in the session or retrieving it later on.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Plugs v1.1.0 - Changelog","doc":"This is the changelog for Cldr Plugs v1.1.0 released on July 17th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_plugs/tags)","ref":"changelog.html#cldr-plugs-v1-1-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `:assigns` as an optional source of the locale in `Cldr.Plug.SetLocale`.  The library [ex_cldr_routes](https://hex.pm/packages/ex_cldr_routes) introduces localised routing. These localised routes will set the `conn.assigns[:cldr_locale]` and therefore may be used as an indicator of the users locale preference if no other locale source (like the session, path or params) can be identified. Since the routes locale is tied to the route, not necessarily the users preference, this should be considered a lower priority locale source.  The default `:from` parameter is updated to reflect this and is now set to `[:session, :accept_language, :query, :path, :assigns]`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Plugs v1.0.0 - Changelog","doc":"This is the changelog for Cldr Plugs v1.0.0 released on May 10th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_plugs/tags)","ref":"changelog.html#cldr-plugs-v1-0-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Intiial release, extracted from `ex_cldr`\n\n* Adds support for [MFA](https://elixirforum.com/t/documentation-of-what-an-mfa-is/25376) (and the variant without arguments `MF`) tuples that can be used as part of the `Cldr.Plug.SetLocale` configuration in the `:from` and `:default` cases.","ref":"changelog.html#enhancements"},{"type":"extras","title":"LICENSE","doc":"","ref":"license.html"},{"type":"extras","title":"License - LICENSE","doc":"Copyright 2017 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","ref":"license.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}